nsi.granulate.tests.testGranulatePDF.TestGranulatePDF

Package nsi :: Package granulate :: Package tests :: Module testGranulatePDF :: Class TestGranulatePDF |
[hide private]
[frames] | no frames]

# Class TestGranulatePDF

source code

           object --+
                    |
    unittest.TestCase --+
                        |
                       TestGranulatePDF

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
createInstanceGraPDF(self) | source code
testCheckCreateInstanceGranPDF(self) This test passes arguments the old way. | source code
testGranulateDocument(self) This test passes arguments the old way. | source code
testGetTableDocumentList(self) This test passes arguments the old way. | source code
testGetImageDocumentList(self) This test passes arguments the old way. | source code
Inherited from `unittest.TestCase`: `__call__`, `__init__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `setUp`, `shortDescription`, `tearDown` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`